@@ -219,12 +219,12 @@ def create_listener(
         test_definitions,
         return_message_handler,
 ):
+    """Setup and create listener"""
     import ui
     from pathlib import Path
 
     ui_path = Path(ui.__path__[0], 'build')
 
-    """Setup and create listener"""
     init = {'test_control': test_control, 'test_definitions': test_definitions}
 
     app = tornado.web.Application(
@@ -250,7 +250,7 @@ def create_listener(
             (r"/api/testcontrol", TestRunnerHandler, init),
             (r"/api/testcontrol/([0-9]+)", TestRunnerHandler, init),
             (r"/(.*\.(js|json|html|css))", tornado.web.StaticFileHandler, {'path': ui_path}),
-            (r"/(.*)", UiEntryHandler, {'path': 'ui/build/', "default_filename": "index.html"}),
+            (r"/(.*)", UiEntryHandler, {'path': ui_path, "default_filename": "index.html"}),
         ]
     )
 
